#import "PictureSelectorPlugin.h"
#import <TZImagePickerController.h>
#define SCREEN_WIDTH ([[UIScreen mainScreen] bounds].size.width)
#define SCREEN_HEIGHT ([[UIScreen mainScreen] bounds].size.height)

@interface PictureSelectorPlugin ()

@property (strong, nonatomic) UIViewController *viewController;
@property (strong, nonatomic) NSMutableDictionary *selectedAssetDic;

@end

@implementation PictureSelectorPlugin

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel
                                     methodChannelWithName:@"picture_selector"
                                     binaryMessenger:[registrar messenger]];
    UIViewController *viewController =
    [UIApplication sharedApplication].delegate.window.rootViewController;
    PictureSelectorPlugin* instance = [[PictureSelectorPlugin alloc] initWithViewController:viewController];
    [registrar addMethodCallDelegate:instance channel:channel];
}

- (instancetype)initWithViewController:(UIViewController *)viewController {
    self = [super init];
    if (self) {
        self.selectedAssetDic = @{}.mutableCopy;
        _viewController = viewController;
    }
    return self;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if ([@"select" isEqualToString:call.method]) {
        NSDictionary *argsMap = call.arguments;
        NSInteger type = [argsMap[@"type"] integerValue];
        NSInteger max = [argsMap[@"max"] integerValue];
        BOOL isCamera = [argsMap[@"isCamera"] boolValue];
        BOOL enableCrop = [argsMap[@"enableCrop"] boolValue];
        BOOL compress = [argsMap[@"compress"] boolValue];
        NSInteger ratioX = [argsMap[@"ratioX"] integerValue];
        NSInteger ratioY = [argsMap[@"ratioY"] integerValue];
        NSArray *selectList = [NSArray arrayWithArray:argsMap[@"selectList"]];
        NSMutableArray *selectedAssets = @[].mutableCopy;
        [selectList enumerateObjectsUsingBlock:^(NSString * _Nonnull path, NSUInteger idx, BOOL * _Nonnull stop) {
            PHAsset *asset = self.selectedAssetDic[path];
            [selectedAssets addObject:asset];
        }];
        TZImagePickerController *imagePickerVc = [[TZImagePickerController alloc] initWithMaxImagesCount:1 delegate:self];
        imagePickerVc.allowPickingVideo = type != 1;
        imagePickerVc.allowPickingImage = type != 2;
        imagePickerVc.maxImagesCount = max;
        imagePickerVc.allowPickingOriginalPhoto = false;
        imagePickerVc.allowTakePicture = isCamera;
        imagePickerVc.allowPickingGif = false;
        imagePickerVc.allowPickingMultipleVideo = max != 1;
        imagePickerVc.allowCrop = enableCrop;
        imagePickerVc.scaleAspectFillCrop = true;
        imagePickerVc.selectedAssets = selectedAssets;
        NSInteger top = (SCREEN_HEIGHT - SCREEN_WIDTH * ratioY / ratioX) / 2;
        imagePickerVc.cropRect = CGRectMake(0, top, SCREEN_WIDTH, SCREEN_WIDTH * ratioY / ratioX);
        [imagePickerVc setDidFinishPickingPhotosHandle:^(NSArray<UIImage *> *photos, NSArray *assets, BOOL flag) {
            NSMutableArray *pathArray = @[].mutableCopy;
            [photos enumerateObjectsUsingBlock:^(UIImage * _Nonnull subImage, NSUInteger idx, BOOL * _Nonnull stop) {
                NSData *imageData = UIImageJPEGRepresentation(subImage, 0.5);
                UIImage *newImage = [UIImage imageWithData:imageData];
                NSString *path = [self getImagePath:newImage withCompress:compress withImageName:[NSString stringWithFormat:@"/%@.png", self.currentTimeStr]];
                NSMutableDictionary *dic = @{}.mutableCopy;
                if(compress){
                    dic[@"compressPath"] = path;
                }
                if(enableCrop){
                    dic[@"cropPath"] = path;
                }
                dic[@"path"] = path;
                [pathArray addObject:dic];
                PHAsset *asset = assets[idx];
                self->_selectedAssetDic[path] = asset;
            }];
            result(pathArray);
        }];
        [_viewController presentViewController:imagePickerVc animated:YES completion:nil];
    } else {
        result(FlutterMethodNotImplemented);
    }
}

-(NSString *)getImagePath:(UIImage *)Image withCompress:(BOOL)compress withImageName:(NSString *)imageName {
    NSString * filePath = nil;
    NSData * data = nil;
    if (UIImagePNGRepresentation(Image) == nil) {
        if(compress){
            data = UIImageJPEGRepresentation(Image, 0.2);
        } else {
            data = UIImageJPEGRepresentation(Image, 0.5);
        }
    } else {
        data = UIImagePNGRepresentation(Image);
    }
    //图片保存的路径
    //这里将图片放在沙盒的documents文件夹中
    NSString *DocumentsPath = [NSHomeDirectory() stringByAppendingPathComponent:@"Documents"];
    //文件管理器
    NSFileManager *fileManager = [NSFileManager defaultManager];
    //把刚刚图片转换的data对象拷贝至沙盒中
    [fileManager createDirectoryAtPath:DocumentsPath withIntermediateDirectories:YES attributes:nil error:nil];
    NSString * ImagePath = imageName;
    [fileManager createFileAtPath:[DocumentsPath stringByAppendingString:ImagePath] contents:data attributes:nil];
    //得到选择后沙盒中图片的完整路径
    filePath = [[NSString alloc]initWithFormat:@"%@%@",DocumentsPath,ImagePath];
    return filePath;
}

- (NSString *)currentTimeStr{
    NSDate* date = [NSDate dateWithTimeIntervalSinceNow:0];//获取当前时间0秒后的时间
    NSTimeInterval time=[date timeIntervalSince1970]*1000;// *1000 是精确到毫秒，不乘就是精确到秒
    NSString *timeString = [NSString stringWithFormat:@"%.0f", time];
    return timeString;
}
@end
